==> haskell-free-5.1.10-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 free
version:              5.1.10
visibility:           public
id:                   free-5.1.10-23hOCadlfcOJLspOEiGZCI
key:                  free-5.1.10-23hOCadlfcOJLspOEiGZCI
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/free/
synopsis:             Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.

    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.

    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.

    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>

category:             Control, Monads
abi:                  0b665b8da84f21d45ed7d3947d2dfcf8
exposed:              True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter

hidden-modules:       Data.Functor.Classes.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/free-5.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/free-5.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-free
hs-libraries:         HSfree-5.1.10-23hOCadlfcOJLspOEiGZCI
includes:             free-common.h
depends:
    base-4.16.4.0 comonad-5.0.8-LbmfypspQsCFliUg0oA4ZK
    containers-0.6.5.1 distributive-0.6.2.1-2vkrNjrf7S12Af99vZevt
    exceptions-0.10.4 indexed-traversable-0.1.4-8zY0DDBVupTDQCUfZOnGAP
    mtl-2.2.2 profunctors-5.6.2-7EvXszvdoMRIenez5xMjgl
    semigroupoids-5.3.7-2Bbz5Qu2PBmJORnT4d1pIg
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2
    transformers-base-0.4.6-4mLyiZ1lYe32soo1Zji4lM

haddock-interfaces:   /usr/share/doc/haskell-free/html/free.haddock
haddock-html:         /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-5.1.10-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 free
version:              5.1.10
visibility:           public
id:                   free-5.1.10-9iwzMICW5PLLGiZttBbEE7
key:                  free-5.1.10-9iwzMICW5PLLGiZttBbEE7
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/free/
synopsis:             Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.

    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.

    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.

    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>

category:             Control, Monads
abi:                  225ebd81ad3566bdeab773fef88fccb1
exposed:              True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter

hidden-modules:       Data.Functor.Classes.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/free-5.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/free-5.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-free
hs-libraries:         HSfree-5.1.10-9iwzMICW5PLLGiZttBbEE7
includes:             free-common.h
depends:
    base-4.16.4.0 comonad-5.0.8-Eky328ZCag5CAyHmtRF67N
    containers-0.6.5.1 distributive-0.6.2.1-F2oLlehQgIZ2bsrVtqD2Nm
    exceptions-0.10.4 indexed-traversable-0.1.4-6DxS8AAQhLPFeQTrRdgvCS
    mtl-2.2.2 profunctors-5.6.2-6jNxDGZrnPBFtYN99i2z7g
    semigroupoids-5.3.7-KoVG55KLWm02seDfmMf2t0
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2
    transformers-base-0.4.6-49q3ABY5SL9GSCeyTZR1jM

haddock-interfaces:   /usr/share/doc/haskell-free/html/free.haddock
haddock-html:         /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
